@@ -22,7 +22,21 @@ class SidecarNotFoundError(Exception):
         super().__init__(self.message)
 
 
-def guess_companion_path(granule_path, prefix=None, folder=None):
+class CompanionNotFoundError(Exception):
+    def __init__(self, file_path):
+        self.file_path = file_path
+        self.message = 'Could not find companion for {}'.format(file_path)
+        super().__init__(self.message)
+
+
+class MultipleCompanionsFoundError(Exception):
+    def __init__(self, file_path):
+        self.file_path = file_path
+        self.message = 'More than one possible companion found for {}. Specify the prefix'.format(file_path)
+        super().__init__(self.message)
+
+
+def guess_companion_path(granule_path, folder=None, prefix=None):
     """
     Tries to find a companion to the granule.
     The assumption being that granule file names are composed of
@@ -32,32 +46,41 @@ def guess_companion_path(granule_path, prefix=None, folder=None):
     -----------
     granule_path: str
         The path of the granule to find the companion for
+    folder: str
+        the folder to look for companions
     prefix: str
-        The pri
+        The prefix of the companion name; e.g. VJ102DNB
+
+    Examples
+    ---------
+    >>> granule_path = starepandas.datasets.get_path('VNP02DNB.A2020219.0742.001.2020219125654.nc')
+    >>> companion_path = guess_companion_path(granule_path, prefix='VNP03DNB')
+    >>> companion_name = companion_path.split('/')[-1]
+    >>> companion_name
+    'VNP03DNB.A2020219.0742.001.2020219124651.nc'
     """
 
-    if not folder:
+    if folder is None:
         folder = '/'.join(granule_path.split('/')[0:-1])
     name = granule_path.split('/')[-1]
     name_parts = name.split('.')
     date = name_parts[1]
     time = name_parts[2]
     if prefix:
-        pattern = '{folder}/{prefix}.*\\.{date}.{time}\\..*[^_stare]\\.(nc|hdf|HDF5)'
+        pattern = '{folder}/*{prefix}.*\\.{date}.{time}\\..*[^_stare]\\.(nc|hdf|HDF5)'
         pattern = pattern.format(folder=folder, prefix=prefix, date=date, time=time)
     else:
-        pattern = '{folder}/.*\\.{date}.{time}\\..*[^_stare]\\.(nc|hdf|HDF5)'
+        pattern = '{folder}/*.*\\.{date}.{time}\\..*[^_stare]\\.(nc|hdf|HDF5)'
         pattern = pattern.format(folder=folder, date=date, time=time)
     matches = glob.glob(folder + '/*')
-    granules = list(filter(re.compile(pattern).match, matches))
-    if len(granules) < 1 or granules[0] == granule_path:
-        print('did not find companion')
-        return None
-    if len(granules) > 1:
-        print('more than one possible match found. Specify the prefix!')
-        print(granules)
+    companions = set(filter(re.compile(pattern).match, matches))
+    companions = list(companions - set([granule_path]))
+    if len(companions) < 1 or companions[0] == granule_path:
+        raise CompanionNotFoundError(granule_path)
+    if len(companions) > 1:
+        raise MultipleCompanionsFoundError(granule_path)
     else:
-        return granules[0]
+        return companions[0]
 
 
 def granule_factory(file_path, sidecar_path=None):
@@ -83,26 +106,28 @@ def granule_factory(file_path, sidecar_path=None):
     return granule
 
 
-def read_granule(file_path, latlon=False, sidecar=False, sidecar_path=None, add_stare=False, adapt_resolution=True,
-                 **kwargs):
+def read_granule(file_path, latlon=False, sidecar=False, sidecar_path=None, add_stare=False, adapt_resolution=True):
     """ Reads a granule into a STAREDataFrame
 
-    :param file_path: path of the granule
-    :type file_path: string
-    :param latlon: toggle whether to read the latitude and longitude variables
-    :type latlon: bool
-    :param sidecar: toggle whether to read the sidecar file
-    :type sidecar: bool
-    :param sidecar_path: path of the sidecar file. If not provided, it is assumed to be ${file_path}_stare.nc
-    :type sidecar_path: string
-    :param add_stare: toggle whether to lookup stare indices
-    :type add_stare: bool
-    :param adapt_resolution: toggle whether to adapt the resolution
-    :type adapt_resolution: bool
-    :param kwargs:
-    :type kwargs:
-    :return: stare dataframe
-    :rtype: starepandas.STAREDataFrame
+    Parameters
+    -----------
+    file_path: str
+        path of the granule
+    latlon: bool
+        toggle whether to read the latitude and longitude variables
+    sidecar: bool
+        toggle whether to read the sidecar file
+    sidecar_path: str
+        path of the sidecar file. If not provided, it is assumed to be ${file_path}_stare.nc
+    add_stare: bool
+        toggle whether to lookup stare indices
+    adapt_resolution: bool
+        toggle whether to adapt the resolution
+
+    Returns
+    --------
+    df: starepandas.STAREDataFrame
+        A dataframe holding the granule data
 
     Examples
     ----------
@@ -126,4 +151,5 @@ def read_granule(file_path, latlon=False, sidecar=False, sidecar_path=None, add_
     elif add_stare:
         granule.add_stare(adapt_resolution)
 
-    return granule.to_df()
+    df = granule.to_df()
+    return df
