@@ -12,17 +12,26 @@ import pystare
 import multiprocessing
 
 
-def stare_from_gdf(gdf, level=-1, convex=False, force_ccw=True, n_workers=1):
+def sids_from_gdf(gdf, resolution, convex=False, force_ccw=True, n_workers=1):
     """
     Takes a GeoDataFrame and returns a corresponding series of sets of trixel indices
 
-    :param gdf: A geopandas.GeoDataFrame containing features to look (sets of) STARE indices up for
-    :param level: STARE level
-    :param convex: Toggle if STARE indices for the convex hull rather than the G-Ring should be looked up
-    :param force_ccw: Toggle if a counter clockwise orientation of the geometries should be enforced
-    :param n_workers: Number of workers used to lookup STARE indices in parallel
-    :return: A numpy array of length=len(gdf.index) holding the set of stare indices of each geometry
-    :rtype: numpy.ndarray
+    Parameters
+    -----------
+    gdf: geopandas.GeoDataFrame
+        A dataframe containing features to look (sets of) STARE indices up for
+    resolution: int
+        STARE resolution
+    convex: bool
+        Toggle if STARE indices for the convex hull rather than the G-Ring should be looked up
+    force_ccw: bool
+        Toggle if a counter clockwise orientation of the geometries should be enforced
+    n_workers: int
+        Number of workers used to lookup STARE indices in parallel
+
+    Returns
+    --------
+    A numpy array of length=len(gdf.index) holding the set of stare indices of each geometry
 
     Examples
     ---------
@@ -30,7 +39,7 @@ def stare_from_gdf(gdf, level=-1, convex=False, force_ccw=True, n_workers=1):
     >>> import starepandas
     >>> world = geopandas.read_file(geopandas.datasets.get_path('naturalearth_lowres'))
     >>> italy = world[world.name=='Italy']
-    >>> starepandas.stare_from_gdf(italy, level=3, convex=False, force_ccw=True, n_workers=1)
+    >>> starepandas.sids_from_gdf(italy, resolution=3, convex=False, force_ccw=True, n_workers=1)
     [array([4269412446747230211, 4548635623644200963, 4566650022153682947,
            4548635623644200963, 4548635623644200963])]
     """
@@ -43,22 +52,32 @@ def stare_from_gdf(gdf, level=-1, convex=False, force_ccw=True, n_workers=1):
         # This might be a speedup since we don't need to iterate over python lists
         lat = gdf.geometry.y
         lon = gdf.geometry.x
-        return pystare.from_latlon(lat, lon, level)
+        return pystare.from_latlon(lat, lon, resolution)
     else:
-        return stare_from_geoseries(gdf.geometry, level=level, convex=convex, force_ccw=force_ccw, n_workers=n_workers)
+        return sids_from_geoseries(gdf.geometry, resolution=resolution, convex=convex, force_ccw=force_ccw, n_workers=n_workers)
 
 
-def stare_from_geoseries(series, level=0, convex=False, force_ccw=True, n_workers=1):
+def sids_from_geoseries(series, resolution, convex=False, force_ccw=True, n_workers=1):
     """
     Takes a GeoSeries and returns a corresponding series of sets of trixel indices
 
-    :param series: A geopandas.GeoSeries containing features to look (sets of) STARE indices up for
-    :param level: STARE level
-    :param convex: Toggle if STARE indices for the convex hull rather than the G-Ring should be looked up
-    :param force_ccw: Toggle if a counter clockwise orientation of the geometries should be enforced
-    :param n_workers: Number of workers used to lookup STARE indices in parallel
-    :return: A numpy array of length=len(gdf.index) holding the set of stare indices of each geometry
-    :rtype: numpy.ndarray
+    Parameters
+    -----------
+    series: geopandas.GeoSeries
+        A geopandas.GeoSeries containing features to look (sets of) STARE indices up for
+    resolution: int
+        STARE resolution
+    convex: bool
+        Toggle if STARE indices for the convex hull rather than the G-Ring should be looked up
+    force_ccw: bool
+        Toggle if a counter clockwise orientation of the geometries should be enforced
+    n_workers: int
+        Number of workers used to lookup STARE indices in parallel
+    
+    Returns
+    --------
+    sids
+        A numpy array of length=len(gdf.index) holding the set of stare indices of each geometry
 
     Examples
     ------------
@@ -66,7 +85,7 @@ def stare_from_geoseries(series, level=0, convex=False, force_ccw=True, n_worker
     >>> import starepandas
     >>> world = geopandas.read_file(geopandas.datasets.get_path('naturalearth_lowres'))
     >>> germany = world[world.name=='Germany']
-    >>> starepandas.stare_from_geoseries(germany.geometry, level=3, convex=True)
+    >>> starepandas.sids_from_geoseries(germany.geometry, resolution=3, convex=True)
     [array([4251398048237748227, 4269412446747230211, 4278419646001971203,
            4539628424389459971, 4548635623644200963, 4566650022153682947])]
     """
@@ -77,55 +96,68 @@ def stare_from_geoseries(series, level=0, convex=False, force_ccw=True, n_worker
     if n_workers == 1:
         stare = []
         for geom in series:
-            sids = stare_from_shapely(geom=geom, level=level, convex=convex, force_ccw=force_ccw)
+            sids = sids_from_shapely(geom=geom, resolution=resolution, convex=convex, force_ccw=force_ccw)
             stare.append(sids)
     else:
         ddf = dask.dataframe.from_pandas(series, npartitions=n_workers)
         meta = {'stare': 'int64'}
-        res = ddf.map_partitions(lambda df: numpy.array(stare_from_geoseries(df, level, convex, force_ccw, 1)),
+        res = ddf.map_partitions(lambda df: numpy.array(sids_from_geoseries(df, resolution, convex, force_ccw, 1)),
                                  meta=meta)
         stare = res.compute(scheduler='processes')
     return stare
 
 
-def stare_from_xy(lon, lat, level=0):
+def sids_from_xy(lon, lat, resolution):
     """Takes a list/array of lon and lat and returns a (set of) STARE index/ices
 
-    :param lon: Longitude of point
-    :param lat: Latitude of point
-    :param level: STARE Level
-    :return: Array of STARE index values
-    :rtype: numpy.ndarray
+    Parameters
+    -----------
+    lon: numerical/float
+        Longitude of point
+    lat: numerical/float
+        Latitude of point
+    resolution: int
+        STARE spatial resolution
+
+    Returns
+    ----------
+    sids
+        Array of STARE index values
 
     Examples
     ----------
     >>> import starepandas
     >>> x = [10.1, 20.9]
     >>> y = [55.3, 60.1]
-    >>> starepandas.stare_from_xy(x, y, level=15)
+    >>> starepandas.sids_from_xy(x, y, resolution=15)
     array([4254264869405326191, 3640541580264132591])
     """
-    return pystare.from_latlon(lat, lon, level)
+    return pystare.from_latlon(lat, lon, resolution)
 
 
-def stare_row(row, level):
+def sids_from_latlon_row(row, resolution):
     """ Dask helper function """
-    return pystare.from_latlon(row.lat, row.lon, level)
+    return pystare.from_latlon(row.lat, row.lon, resolution)
 
 
-def stare_from_xy_df(df, level=0, n_workers=1):
+def sids_from_xy_df(df, resolution, n_workers=1):
     """ Takes a dataframe and generates an array of STARE index values.
     Assumes latitude column name is {'lat', 'Latitude', 'latitude', or 'y'} and
     longitude column name is {'lon', 'Longitude', 'longitude', or 'x'}
 
-    :param df: Dataframe containing x/y coordinates
-    :type df: pandas.DataFrame
-    :param level: STARE Level
-    :type level: int
-    :param n_workers: Number of workers used to lookup STARE indices in parallel
-    :type n_workers: int
-    :return: Array of STARE index values
-    :rtype: numpy.ndarray
+    Parameters 
+    --------------
+    df: pandas.DataFrame
+        Dataframe containing x/y coordinates    
+    resolution: int
+        STARE spatial resolution    
+    n_workers: int
+        Number of workers used to lookup STARE indices in parallel
+        
+    Returns
+    --------
+    sids     
+        Array of STARE index values    
 
     Examples
     ------------
@@ -134,42 +166,47 @@ def stare_from_xy_df(df, level=0, n_workers=1):
     >>> x = [-119.42, 7.51]
     >>> y = [34.25, 47.59]
     >>> df = pandas.DataFrame({'lat': y, 'lon': x})
-    >>> starepandas.stare_from_xy_df(df, level=20)
+    >>> starepandas.sids_from_xy_df(df, resolution=20)
     array([3331752989521980116, 4271829667422230484])
     """
-    rename_dict = {'Latitude' : 'lat', 'latitude': 'lat', 'y': 'lat',
+    rename_dict = {'Latitude': 'lat', 'latitude': 'lat', 'y': 'lat',
                    'Longitude': 'lon', 'longitude': 'lon', 'x': 'lon'}
     df = df.rename(columns=rename_dict)
     if n_workers > 1:
         ddf = dask.dataframe.from_pandas(df, npartitions=n_workers)
-        return ddf.map_partitions(stare_row, level, meta=('stare', 'int')).compute(scheduler='processes')
+        return ddf.map_partitions(sids_from_latlon_row, resolution, meta=('stare', 'int')).compute(scheduler='processes')
     else:
-        return pystare.from_latlon(df.lat, df.lon, level)
+        return pystare.from_latlon(df.lat, df.lon, resolution)
 
 
-def stare_from_geom_row(row, level):
+def sids_from_geom_row(row, resolution):
     """ Dask Helper function"""
-    return stare_from_shapely(row.geometry)
+    return sids_from_shapely(geom=row.geometry, resolution=resolution)
 
 
-def stare_from_shapely(geom, level, convex=False, force_ccw=False):
+def sids_from_shapely(geom, resolution, convex=False, force_ccw=False):
     """ Wrapper for starepandas.from_point(), starepandas.from_ring(),
     starepandas.from_polygon(), starepandas.from_multipolygon()
 
     Takes a shapely Point, Polygon, or Multipolygon and looks up the STARE representation
 
-    :param geom: A shapely geometry to look the sids up for
-    :type geom: shapely.geometry.Point, shapely.geometry.Polygon, shapely.geometry.MultiPolygon
-    :param level: Maximum STARE level to use for lookup
-    :type level: int
-    :param convex: Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry
+    Parameters
+    -------------
+    geom: shapely.geometry.Point, shapely.geometry.Polygon, shapely.geometry.MultiPolygon
+        A shapely geometry to look the sids up for
+    resolution: int
+        Maximum STARE resolution to use for lookup
+    convex: bool
+        Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry
         of the polygon.
-    :type convex: bool
-    :param force_ccw: Toggle if counter-clockwise should be forced. Counter clockwise meaning that the
+    force_ccw: bool
+        Toggle if counter-clockwise should be forced. Counter clockwise meaning that the
         "inside" of a ring will always be left of its vertices and edges.
-    :type force_ccw: bool
-    :return: collection of sids
-    :rtype: array-like
+
+    Returns
+    ---------
+    sids:
+        collection of sids
 
     Examples
     ---------
@@ -179,56 +216,61 @@ def stare_from_shapely(geom, level, convex=False, force_ccw=False):
     Point:
 
     >>> point = shapely.geometry.Point(10.5, 20)
-    >>> starepandas.stare_from_shapely(point, level=27)
+    >>> starepandas.sids_from_shapely(point, resolution=27)
     4598246232954051067
 
     Polygon:
 
     >>> polygon1 = shapely.geometry.Polygon([(0, 0), (1, 1), (1, 0)])
-    >>> starepandas.stare_from_shapely(polygon1, force_ccw=True, level=6)
+    >>> starepandas.sids_from_shapely(polygon1, force_ccw=True, resolution=6)
     array([4430697608402436102, 4430838345890791430, 4430979083379146758])
 
     Multipolygon:
 
     >>> polygon2 = shapely.geometry.Polygon([(5, 5), (6, 6), (6, 5)])
     >>> multipolygon = shapely.geometry.MultiPolygon([polygon1, polygon2])
-    >>> starepandas.stare_from_shapely(multipolygon, force_ccw=True, level=5)
+    >>> starepandas.sids_from_shapely(multipolygon, force_ccw=True, resolution=5)
     array([4430416133425725445, 4430979083379146757, 4416905334543613957])
 
     """
     if geom.geom_type == 'Point':
-        return stare_from_point(geom, level=level)
+        return sid_from_point(geom, resolution=resolution)
     if geom.geom_type == 'Polygon':
-        return stare_from_polygon(geom, level=level, convex=convex, force_ccw=force_ccw)
+        return sids_from_polygon(geom, resolution=resolution, convex=convex, force_ccw=force_ccw)
     if geom.geom_type == 'MultiPolygon':
-        return stare_from_multipolygon(geom, level=level, convex=convex, force_ccw=force_ccw)
+        return sids_from_multipolygon(geom, resolution=resolution, convex=convex, force_ccw=force_ccw)
 
 
-def stare_from_point(point, level=-1):
-    """Takes a shapely Point, Polygon, or Multipolygon and looks up the STARE representation
+def sid_from_point(point, resolution):
+    """Takes a shapely Point, Polygon, or Multipolygon and returns the according SID
 
-    :param point: Shapely point
-    :type point: shapely.geometry.Point
-    :param level: STARE level to use for lookup
-    :type level: int
-    :return: collection of sids
-    :rtype: array-like
+    Parameters
+    -------------
+    point: shapely.geometry.Point
+        Shapely point
+    resolution: int
+        STARE resolution to use for lookup
+
+    Returns
+    ----------
+    sid
+        spatial index value
 
     Examples
     ---------
     >>> import starepandas
     >>> import shapely
     >>> point = shapely.geometry.Point(10.5, 20)
-    >>> starepandas.stare_from_point(point, level=20)
+    >>> starepandas.sid_from_point(point, resolution=20)
     4598246232954051060
     """
     lat = point.y
     lon = point.x
-    index_value = pystare.from_latlon([lat], [lon], level)[0]
+    index_value = pystare.from_latlon([lat], [lon], resolution)[0]
     return index_value
 
 
-def stare_from_ring(ring, level=-1, convex=False, force_ccw=False):
+def sids_from_ring(ring, resolution, convex=False, force_ccw=False):
     """
     Return a range of indices covering the region inside/outside ring.
     Node orientation is relevant!
@@ -237,8 +279,8 @@ def stare_from_ring(ring, level=-1, convex=False, force_ccw=False):
     ------------
     ring: shapely.geometry.polygon.LinearRing
         Ring to lookup sids for
-    level: int
-        (Maximum) STARE level to use for lookup. Warning: default is maximum level (27)
+    resolution: int
+        Maximum STARE resolution to use for lookup.
     convex: bool
         Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry of the ring
     force_ccw: bool
@@ -254,7 +296,7 @@ def stare_from_ring(ring, level=-1, convex=False, force_ccw=False):
     >>> import shapely
     >>> # Note: the ring is clockwise!
     >>> polygon = shapely.geometry.Polygon([(0, 0), (1, 1), (1, 0)])
-    >>> starepandas.stare_from_ring(polygon.exterior, force_ccw=True, level=6)
+    >>> starepandas.sids_from_ring(polygon.exterior, force_ccw=True, resolution=6)
     array([4430697608402436102, 4430838345890791430, 4430979083379146758])
     """
     if force_ccw and not ring.is_ccw:
@@ -263,50 +305,55 @@ def stare_from_ring(ring, level=-1, convex=False, force_ccw=False):
     lon = latlon[0]
     lat = latlon[1]
     if convex:
-        range_indices = pystare.cover_from_hull(lat, lon, level)
+        range_indices = pystare.cover_from_hull(lat, lon, resolution)
     else:
-        range_indices = pystare.cover_from_ring(lat, lon, level)
+        range_indices = pystare.cover_from_ring(lat, lon, resolution)
 
     return range_indices
 
 
-def stare_from_polygon(polygon, level=-1, convex=False, force_ccw=False):
+def sids_from_polygon(polygon, resolution, convex=False, force_ccw=False):
     """ Lookup STARE index values for a polygon.
     A Polygon is a planar Surface defined by 1 exterior ring and 0 or more interior boundaries. Each interior
     ring defines a hole in the Polygon.
 
-    :param polygon: Polygon to look sids up for
-    :type polygon: shapely.geometry.Polygon
-    :param level: (Maximum) STARE level to use for lookup: Warning: default is maximum level (27)
-    :type level: int
-    :param convex: Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry.
+    Parameters
+    --------------
+    polygon: shapely.geometry.Polygon
+        Polygon to look sids up for
+    resolution: int
+        Maximum STARE resolution to use for lookup
+    convex: bool
+        Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry.
         This will be applied for both the exterior ring and the interior rings.
-    :type convex: bool
-    :param force_ccw: toggle if orientation of ring should be overwritten and ring should be interpreted as outer
+    force_ccw: bool
+        toggle if orientation of ring should be overwritten and ring should be interpreted as outer
         boundary. Note: Interior rings will always be forced to be clockwise!
-    :type force_ccw: Bool
-    :return: collection of sids
-    :rtype: array-like
+
+    Returns
+    ------------
+    sids:
+        collection of sids
 
     Examples
     ---------
     >>> import starepandas
     >>> import shapely
     >>> polygon = shapely.geometry.Polygon([(0, 0), (2, 0), (1, 1)])
-    >>> starepandas.stare_from_polygon(polygon, level=5)
+    >>> starepandas.sids_from_polygon(polygon, resolution=5)
     array([4423097784031248389, 4430416133425725445, 4430979083379146757])
     """
 
     if force_ccw:
         polygon = shapely.geometry.polygon.orient(polygon)
-    sids_ext = stare_from_ring(polygon.exterior, level, convex, force_ccw)
+    sids_ext = sids_from_ring(polygon.exterior, resolution, convex, force_ccw)
 
     if len(polygon.interiors) > 0:
         sids_int = []
         for interior in polygon.interiors:
             if interior.is_ccw:
                 interior.coords = list(interior.coords)[::-1]
-            sids_int.append(stare_from_ring(interior, level, convex, force_ccw=False))
+            sids_int.append(sids_from_ring(interior, resolution, convex, force_ccw=False))
         sids_int = numpy.concatenate(sids_int)
         sids = pystare.intersection(sids_int, sids_ext)
     else:
@@ -314,21 +361,26 @@ def stare_from_polygon(polygon, level=-1, convex=False, force_ccw=False):
     return sids
 
 
-def stare_from_multipolygon(multipolygon, level=-1, convex=False, force_ccw=False):
+def sids_from_multipolygon(multipolygon, resolution, convex=False, force_ccw=False):
     """ Lookup STARE index values for a multipolygon.
 
-    :param polygon: Polygon to look sids up for
-    :type polygon: shapely.geometry.Polygon
-    :param level: (Maximum) STARE level to use for lookup: Warning: default is maximum level (27)
-    :type level: int
-    :param convex: Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry.
+    Parameters
+    ------------
+    multipolygon: shapely.geometry.MultiPolygon
+        MultiPolygon to look sids up for
+    resolution: int
+        Maximum STARE resolution to use for lookup
+    convex: bool
+        Toggle if the STARE lookup should be performed on the convex hull rather than the actual geometry.
         This will be applied for both the exterior ring and the interior rings.
-    :type convex: bool
-    :param force_ccw: toggle if orientation of ring should be overwritten and ring should be interpreted as outer
+    force_ccw: bool
+        Toggle if orientation of ring should be overwritten and ring should be interpreted as outer
         boundary. Note: Interior rings will always be forced to be clockwise!
-    :type force_ccw: Bool
-    :return: collection of sids
-    :rtype: array-like
+
+    Returns
+    ---------
+    sids
+        An array of collection of sids
 
     Examples
     ----------
@@ -338,12 +390,12 @@ def stare_from_multipolygon(multipolygon, level=-1, convex=False, force_ccw=Fals
     >>> polygon1 = shapely.geometry.Polygon([(0, 0), (1, 1), (1, 0)])
     >>> polygon2 = shapely.geometry.Polygon([(3, 1), (4, 2), (2, 1)])
     >>> multipolygon = shapely.geometry.MultiPolygon([polygon1, polygon2])
-    >>> starepandas.stare_from_multipolygon(multipolygon, force_ccw=True, level=3)
+    >>> starepandas.sids_from_multipolygon(multipolygon, force_ccw=True, resolution=3)
     array([4422534834077827075, 4413527634823086083, 4422534834077827075])
     """
     range_indices = []
     for polygon in multipolygon.geoms:
-        range_indices.append(stare_from_polygon(polygon, level, convex, force_ccw))
+        range_indices.append(sids_from_polygon(polygon, resolution, convex, force_ccw))
     range_indices = numpy.concatenate(range_indices)
     return range_indices
 
